From: Umesh Nerlige Ramappa <umesh.nerlige.ramappa@intel.com>
To: igt-dev@lists.freedesktop.org
Subject: [igt-dev] [PATCH i-g-t 2/2] tests/drm_fdinfo: Drop active busyness tests for GuC backend
Date: Fri, 31 Mar 2023 19:59:15 +0000 [thread overview]
Message-ID: <20230331195915.5839-3-umesh.nerlige.ramappa@intel.com> (raw)
In-Reply-To: <20230331195915.5839-1-umesh.nerlige.ramappa@intel.com>
With GuC scheduling backends, the context busyness for an active context is
obtained from the GuC FW. The support for this is WIP, so disable tests that
check TEST_BUSY until the feature is implemented.
Signed-off-by: Umesh Nerlige Ramappa <umesh.nerlige.ramappa@intel.com>
---
tests/i915/drm_fdinfo.c | 148 +++++++++++++++++++++-------------------
1 file changed, 79 insertions(+), 69 deletions(-)
diff --git a/tests/i915/drm_fdinfo.c b/tests/i915/drm_fdinfo.c
index 65b8b830..5df33933 100644
--- a/tests/i915/drm_fdinfo.c
+++ b/tests/i915/drm_fdinfo.c
@@ -761,83 +761,93 @@ igt_main
igt_subtest("virtual-idle")
virtual(i915, &ctx->cfg, 0);
- /**
- * Test that a single engine reports load correctly.
- */
- test_each_engine("busy", i915, ctx, e)
- single(i915, ctx, e, TEST_BUSY);
-
- igt_subtest("virtual-busy")
- virtual(i915, &ctx->cfg, TEST_BUSY);
-
- test_each_engine("busy-idle", i915, ctx, e)
- single(i915, ctx, e, TEST_BUSY | TEST_TRAILING_IDLE);
-
- igt_subtest("virtual-busy-idle")
- virtual(i915, &ctx->cfg, TEST_BUSY | TEST_TRAILING_IDLE);
-
- test_each_engine("busy-hang", i915, ctx, e) {
- igt_hang_t hang = igt_allow_hang(i915, ctx->id, 0);
-
- single(i915, ctx, e, TEST_BUSY | FLAG_HANG);
-
- igt_disallow_hang(i915, hang);
- }
-
- igt_subtest("virtual-busy-hang")
- virtual(i915, &ctx->cfg, TEST_BUSY | FLAG_HANG);
-
- /**
- * Test that when one engine is loaded other report no
- * load.
- */
- test_each_engine("busy-check-all", i915, ctx, e)
- busy_check_all(i915, ctx, e, num_engines, classes, num_classes,
- TEST_BUSY);
+ igt_fixture {
+ /**
+ * With GuC scheduling backends, the context busyness for a
+ * active context is obtained from the GUC FW. The support for
+ * this is WIP, so disable tests that check TEST_BUSY until the
+ * feature is implemented.
+ */
+ igt_require(!gem_using_guc_submission(i915));
- test_each_engine("busy-idle-check-all", i915, ctx, e)
- busy_check_all(i915, ctx, e, num_engines, classes, num_classes,
- TEST_BUSY | TEST_TRAILING_IDLE);
+ /**
+ * Test that a single engine reports load correctly.
+ */
+ test_each_engine("busy", i915, ctx, e)
+ single(i915, ctx, e, TEST_BUSY);
- /**
- * Test that when all except one engine are loaded all
- * loads are correctly reported.
- */
- test_each_engine("most-busy-check-all", i915, ctx, e)
- most_busy_check_all(i915, ctx, e, num_engines,
- classes, num_classes,
- TEST_BUSY);
+ igt_subtest("virtual-busy")
+ virtual(i915, &ctx->cfg, TEST_BUSY);
- test_each_engine("most-busy-idle-check-all", i915, ctx, e)
- most_busy_check_all(i915, ctx, e, num_engines,
- classes, num_classes,
- TEST_BUSY | TEST_TRAILING_IDLE);
+ test_each_engine("busy-idle", i915, ctx, e)
+ single(i915, ctx, e, TEST_BUSY | TEST_TRAILING_IDLE);
- /**
- * Test that when all engines are loaded all loads are
- * correctly reported.
- */
- igt_subtest("all-busy-check-all")
- all_busy_check_all(i915, ctx, num_engines, classes, num_classes,
- TEST_BUSY);
+ igt_subtest("virtual-busy-idle")
+ virtual(i915, &ctx->cfg, TEST_BUSY | TEST_TRAILING_IDLE);
- igt_subtest("all-busy-idle-check-all")
- all_busy_check_all(i915, ctx, num_engines, classes, num_classes,
- TEST_BUSY | TEST_TRAILING_IDLE);
+ test_each_engine("busy-hang", i915, ctx, e) {
+ igt_hang_t hang = igt_allow_hang(i915, ctx->id, 0);
- igt_subtest("virtual-busy-all")
- virtual_all(i915, &ctx->cfg, TEST_BUSY);
+ single(i915, ctx, e, TEST_BUSY | FLAG_HANG);
- igt_subtest("virtual-busy-idle-all")
- virtual_all(i915, &ctx->cfg, TEST_BUSY | TEST_TRAILING_IDLE);
+ igt_disallow_hang(i915, hang);
+ }
- igt_subtest("virtual-busy-hang-all")
- virtual_all(i915, &ctx->cfg, TEST_BUSY | FLAG_HANG);
- /**
- * Test for no cross-client contamination.
- */
- test_each_engine("isolation", i915, ctx, e)
- single(i915, ctx, e, TEST_BUSY | TEST_ISOLATION);
+ igt_subtest("virtual-busy-hang")
+ virtual(i915, &ctx->cfg, TEST_BUSY | FLAG_HANG);
+
+ /**
+ * Test that when one engine is loaded other report no
+ * load.
+ */
+ test_each_engine("busy-check-all", i915, ctx, e)
+ busy_check_all(i915, ctx, e, num_engines, classes, num_classes,
+ TEST_BUSY);
+
+ test_each_engine("busy-idle-check-all", i915, ctx, e)
+ busy_check_all(i915, ctx, e, num_engines, classes, num_classes,
+ TEST_BUSY | TEST_TRAILING_IDLE);
+
+ /**
+ * Test that when all except one engine are loaded all
+ * loads are correctly reported.
+ */
+ test_each_engine("most-busy-check-all", i915, ctx, e)
+ most_busy_check_all(i915, ctx, e, num_engines,
+ classes, num_classes,
+ TEST_BUSY);
+
+ test_each_engine("most-busy-idle-check-all", i915, ctx, e)
+ most_busy_check_all(i915, ctx, e, num_engines,
+ classes, num_classes,
+ TEST_BUSY | TEST_TRAILING_IDLE);
+
+ /**
+ * Test that when all engines are loaded all loads are
+ * correctly reported.
+ */
+ igt_subtest("all-busy-check-all")
+ all_busy_check_all(i915, ctx, num_engines, classes, num_classes,
+ TEST_BUSY);
+
+ igt_subtest("all-busy-idle-check-all")
+ all_busy_check_all(i915, ctx, num_engines, classes, num_classes,
+ TEST_BUSY | TEST_TRAILING_IDLE);
+
+ igt_subtest("virtual-busy-all")
+ virtual_all(i915, &ctx->cfg, TEST_BUSY);
+
+ igt_subtest("virtual-busy-idle-all")
+ virtual_all(i915, &ctx->cfg, TEST_BUSY | TEST_TRAILING_IDLE);
+
+ igt_subtest("virtual-busy-hang-all")
+ virtual_all(i915, &ctx->cfg, TEST_BUSY | FLAG_HANG);
+ /**
+ * Test for no cross-client contamination.
+ */
+ test_each_engine("isolation", i915, ctx, e)
+ single(i915, ctx, e, TEST_BUSY | TEST_ISOLATION);
+ }
igt_fixture {
intel_ctx_destroy(i915, ctx);
--
2.34.1
next prev parent reply other threads:[~2023-03-31 19:59 UTC|newest]
Thread overview: 7+ messages / expand[flat|nested] mbox.gz Atom feed top
2023-03-31 19:59 [igt-dev] [PATCH i-g-t 0/2] tests/drm_fdinfo: Drop tests with TEST_BUSY for GuC Umesh Nerlige Ramappa
2023-03-31 19:59 ` [igt-dev] [PATCH i-g-t 1/2] lib/drm_fdinfo: Check for compute engines when parsing Umesh Nerlige Ramappa
2023-04-03 10:12 ` Tvrtko Ursulin
2023-03-31 19:59 ` Umesh Nerlige Ramappa [this message]
2023-04-03 10:20 ` [igt-dev] [PATCH i-g-t 2/2] tests/drm_fdinfo: Drop active busyness tests for GuC backend Tvrtko Ursulin
2023-03-31 21:18 ` [igt-dev] ✓ Fi.CI.BAT: success for tests/drm_fdinfo: Drop tests with TEST_BUSY for GuC Patchwork
2023-04-01 21:27 ` [igt-dev] ✓ Fi.CI.IGT: " Patchwork
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20230331195915.5839-3-umesh.nerlige.ramappa@intel.com \
--to=umesh.nerlige.ramappa@intel.com \
--cc=igt-dev@lists.freedesktop.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox